==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","E-mail");
define("_REALNAME","Naam");
define("_FUNCTIONS","Functies");
define("_PREVIOUS","Vorige pagina");
define("_MEMBERSLIST","Ledenlijst");
define("_GREETINGS","Wij verwelkomen ons nieuwste lid:");
define("_SORTBY","Sorteer op:");
define("_MNICKNAME","Inlognaam");
define("_MREALNAME","Naam");
define("_MEMAIL","E-mail");
define("_MURL","url");
define("_ONLINEREG","Online geregistreerde gebruikers:");
define("_WEHAVE","Wij hebben");
define("_MREGISTERED","leden tot nu toe. Er zijn");
define("_MREGONLINE","lid(leden) online op dit moment.");
define("_REGSOFAR","leden tot nu toe.");
define("_USERSFOUND","gebruikers gevonden voor");
define("_USERSSHOWN","gebruikers getoond");
define("_NOMEMBERS","Geen leden gevonden voor");
define("_PAGES","Pagina's");
define("_HOMEPAGE","Homepagina");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Members_List/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","E-mail");
define("_REALNAME","Naam");
define("_FUNCTIONS","Functies");
define("_PREVIOUS","Vorige pagina");
define("_MEMBERSLIST","Ledenlijst");
define("_GREETINGS","Wij verwelkomen ons nieuwste lid:");
define("_SORTBY","Sorteer op:");
define("_MNICKNAME","Inlognaam");
define("_MREALNAME","Naam");
define("_MEMAIL","E-mail");
define("_MURL","url");
define("_ONLINEREG","Online geregistreerde gebruikers:");
define("_WEHAVE","Wij hebben");
define("_MREGISTERED","leden tot nu toe. Er zijn");
define("_MREGONLINE","lid(leden) online op dit moment.");
define("_REGSOFAR","leden tot nu toe.");
define("_USERSFOUND","gebruikers gevonden voor");
define("_USERSSHOWN","gebruikers getoond");
define("_NOMEMBERS","Geen leden gevonden voor");
define("_PAGES","Pagina's");
define("_HOMEPAGE","Homepagina");

?>
